/**
 * OpenAI Style YouTube Block
 */
(function(blocks, element, blockEditor) {
    var el = element.createElement;
    var useBlockProps = blockEditor.useBlockProps;
    var TextControl = wp.components.TextControl;
    var InspectorControls = blockEditor.InspectorControls;
    var PanelBody = wp.components.PanelBody;

    blocks.registerBlockType('my-openai-theme/youtube-embed', {
        title: 'OpenAI YouTube',
        icon: 'video-alt3',
        category: 'media',
        attributes: {
            videoId: {
                type: 'string',
                default: ''
            },
            title: {
                type: 'string',
                default: ''
            }
        },

        edit: function(props) {
            var blockProps = useBlockProps({
                className: 'openai-youtube-block-editor'
            });
            
            var videoId = props.attributes.videoId;
            var title = props.attributes.title;
            
            function onChangeVideoId(newVideoId) {
                props.setAttributes({videoId: extractVideoId(newVideoId)});
            }
            
            function onChangeTitle(newTitle) {
                props.setAttributes({title: newTitle});
            }
            
            function extractVideoId(url) {
                if (!url) return '';
                
                // 既にIDのみの場合
                if (url.length < 20 && !url.includes('/') && !url.includes('.')) {
                    return url;
                }
                
                var videoId = '';
                
                // youtu.beリンクの場合
                if (url.includes('youtu.be/')) {
                    videoId = url.split('youtu.be/')[1];
                }
                // 通常のYouTubeリンクの場合
                else if (url.includes('youtube.com/watch')) {
                    var urlParams = new URLSearchParams(url.split('?')[1]);
                    videoId = urlParams.get('v');
                }
                // 埋め込みリンクの場合
                else if (url.includes('youtube.com/embed/')) {
                    videoId = url.split('youtube.com/embed/')[1];
                }
                
                // クエリパラメータやハッシュを削除
                if (videoId && videoId.includes('?')) {
                    videoId = videoId.split('?')[0];
                }
                if (videoId && videoId.includes('&')) {
                    videoId = videoId.split('&')[0];
                }
                if (videoId && videoId.includes('#')) {
                    videoId = videoId.split('#')[0];
                }
                
                return videoId || '';
            }
            
            var inspectorControls = el(
                InspectorControls,
                {},
                el(
                    PanelBody,
                    { title: 'YouTube設定', initialOpen: true },
                    el(
                        TextControl,
                        {
                            label: 'YouTube URL または 動画ID',
                            value: videoId,
                            onChange: onChangeVideoId,
                            help: 'YouTubeのURLまたは動画IDを入力してください'
                        }
                    ),
                    el(
                        TextControl,
                        {
                            label: '動画タイトル (オプション)',
                            value: title,
                            onChange: onChangeTitle,
                            help: '動画の下に表示されるタイトルを入力してください'
                        }
                    )
                )
            );
            
            var preview;
            if (videoId) {
                var iframeSrc = 'https://www.youtube.com/embed/' + videoId;
                var titleElement = title ? el('div', { className: 'openai-youtube-title' }, title) : null;
                
                preview = el(
                    'div',
                    { className: 'openai-youtube-container' },
                    el(
                        'div',
                        { className: 'openai-youtube-wrapper' },
                        el(
                            'iframe',
                            {
                                src: iframeSrc,
                                frameBorder: '0',
                                allowFullScreen: true,
                                title: 'YouTube video player'
                            }
                        )
                    ),
                    titleElement
                );
            } else {
                preview = el(
                    'div',
                    { className: 'openai-youtube-placeholder' },
                    el('span', {}, 'YouTube URLまたは動画IDを入力してください')
                );
            }
            
            return el(
                'div',
                blockProps,
                inspectorControls,
                preview
            );
        },

        save: function(props) {
            var videoId = props.attributes.videoId;
            var title = props.attributes.title;
            
            if (!videoId) {
                return null;
            }
            
            var iframeSrc = 'https://www.youtube.com/embed/' + videoId;
            var titleElement = title ? el('div', { className: 'openai-youtube-title' }, title) : null;
            
            return el(
                'div',
                { className: 'openai-youtube-container' },
                el(
                    'div',
                    { className: 'openai-youtube-wrapper' },
                    el(
                        'iframe',
                        {
                            src: iframeSrc,
                            frameBorder: '0',
                            allow: 'accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture',
                            allowFullScreen: true,
                            title: 'YouTube video player'
                        }
                    )
                ),
                titleElement
            );
        }
    });
}(
    window.wp.blocks,
    window.wp.element,
    window.wp.blockEditor
)); 