/**
 * OpenAI Style YouTube Embed Script
 */
(function() {
    'use strict';

    document.addEventListener('DOMContentLoaded', function() {
        initOpenAIYouTubeEmbeds();
    });

    /**
     * YouTube埋め込み動画を初期化する
     */
    function initOpenAIYouTubeEmbeds() {
        const containers = document.querySelectorAll('.openai-youtube-container');
        
        containers.forEach(function(container) {
            setupYouTubeEmbed(container);
        });

        // 新しく追加された動画に対応するためのMutationObserver
        const observer = new MutationObserver(function(mutations) {
            mutations.forEach(function(mutation) {
                if (mutation.type === 'childList') {
                    mutation.addedNodes.forEach(function(node) {
                        if (node.nodeType === 1) { // 要素ノードの場合
                            const containers = node.querySelectorAll('.openai-youtube-container');
                            containers.forEach(function(container) {
                                setupYouTubeEmbed(container);
                            });
                        }
                    });
                }
            });
        });

        observer.observe(document.body, { childList: true, subtree: true });
    }

    /**
     * 個々のYouTube埋め込みをセットアップする
     * @param {HTMLElement} container 動画コンテナ要素
     */
    function setupYouTubeEmbed(container) {
        if (container.dataset.initialized) return;
        container.dataset.initialized = 'true';

        const iframe = container.querySelector('iframe');
        if (!iframe) return;

        // YouTubeのIDを取得
        const src = iframe.getAttribute('src');
        let videoId = '';
        
        if (src) {
            // 標準的なYouTube埋め込みリンクからIDを抽出
            if (src.includes('youtube.com/embed/')) {
                videoId = src.split('youtube.com/embed/')[1].split('?')[0];
            }
            // YouTubeの短縮URLからIDを抽出
            else if (src.includes('youtu.be/')) {
                videoId = src.split('youtu.be/')[1].split('?')[0];
            }
        }

        if (!videoId) return;

        // YouTube APIが読み込まれていない場合は読み込む
        if (!window.YT) {
            loadYouTubeAPI();
        }

        // YouTube APIの読み込みを待ってからプレーヤーを作成
        function onYouTubeIframeAPIReady() {
            if (!window.YT || !window.YT.Player) {
                setTimeout(onYouTubeIframeAPIReady, 100);
                return;
            }

            // 既存のiframeをAPIバージョンに置き換える
            const wrapper = container.querySelector('.openai-youtube-wrapper');
            const oldIframe = wrapper.querySelector('iframe');
            const iframeId = 'youtube-' + videoId;
            
            // 新しいdiv要素を作成してiframeを置き換え
            const playerDiv = document.createElement('div');
            playerDiv.id = iframeId;
            wrapper.appendChild(playerDiv);
            if (oldIframe) oldIframe.remove();

            // YouTubeプレーヤーを作成
            const player = new YT.Player(iframeId, {
                videoId: videoId,
                playerVars: {
                    autoplay: 0,
                    controls: 0,
                    showinfo: 0,
                    rel: 0,
                    modestbranding: 1,
                    playsinline: 1,
                    enablejsapi: 1
                },
                events: {
                    'onReady': function(event) {
                        setupCustomControls(container, event.target);
                    }
                }
            });
        }

        // YouTube API読み込み完了後、または既に読み込まれている場合に実行
        if (window.YT && window.YT.Player) {
            onYouTubeIframeAPIReady();
        } else {
            // YT API読み込み完了のイベントハンドラを設定
            window.onYouTubeIframeAPIReady = function() {
                const containers = document.querySelectorAll('.openai-youtube-container[data-initialized="true"]');
                containers.forEach(function(container) {
                    onYouTubeIframeAPIReady();
                });
            };
        }
    }

    /**
     * カスタムコントロールを設定する
     * @param {HTMLElement} container 動画コンテナ要素
     * @param {Object} player YouTubeプレーヤーインスタンス
     */
    function setupCustomControls(container, player) {
        // コントロールエリアを作成
        const controls = document.createElement('div');
        controls.className = 'openai-youtube-controls';
        
        // 再生ボタン
        const playBtn = document.createElement('button');
        playBtn.className = 'openai-youtube-play-btn';
        playBtn.innerHTML = '<svg viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M8 5.14v13.72a.5.5 0 0 0 .77.42l10-6.86a.5.5 0 0 0 0-.84l-10-6.86A.5.5 0 0 0 8 5.14z" fill="currentColor"/></svg>';
        playBtn.setAttribute('aria-label', '再生');
        
        // 停止ボタン
        const pauseBtn = document.createElement('button');
        pauseBtn.className = 'openai-youtube-pause-btn openai-youtube-hidden';
        pauseBtn.innerHTML = '<svg viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg"><rect x="6" y="5" width="4" height="14" rx="1" fill="currentColor"/><rect x="14" y="5" width="4" height="14" rx="1" fill="currentColor"/></svg>';
        pauseBtn.setAttribute('aria-label', '停止');
        
        // コントロールを追加
        controls.appendChild(playBtn);
        controls.appendChild(pauseBtn);
        container.appendChild(controls);
        
        // オーバーレイを追加
        const overlay = document.createElement('div');
        overlay.className = 'openai-youtube-overlay';
        container.appendChild(overlay);
        
        // 再生ボタンのイベントリスナー
        playBtn.addEventListener('click', function() {
            player.playVideo();
            playBtn.classList.add('openai-youtube-hidden');
            pauseBtn.classList.remove('openai-youtube-hidden');
        });
        
        // 停止ボタンのイベントリスナー
        pauseBtn.addEventListener('click', function() {
            player.pauseVideo();
            pauseBtn.classList.add('openai-youtube-hidden');
            playBtn.classList.remove('openai-youtube-hidden');
        });
        
        // プレーヤーの状態変化リスナー
        player.addEventListener('onStateChange', function(event) {
            // 再生中
            if (event.data === YT.PlayerState.PLAYING) {
                playBtn.classList.add('openai-youtube-hidden');
                pauseBtn.classList.remove('openai-youtube-hidden');
            } 
            // 停止中
            else if (event.data === YT.PlayerState.PAUSED) {
                pauseBtn.classList.add('openai-youtube-hidden');
                playBtn.classList.remove('openai-youtube-hidden');
            }
        });
    }

    /**
     * YouTube IFrame API を読み込む
     */
    function loadYouTubeAPI() {
        const tag = document.createElement('script');
        tag.src = 'https://www.youtube.com/iframe_api';
        const firstScriptTag = document.getElementsByTagName('script')[0];
        firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);
    }

})(); 